==> Data-Conveyor-1.102250.tar.gz: Data-Conveyor-1.102250/lib/Data/Conveyor/Value/Enum.pm <==
use 5.008;
use strict;
use warnings;

package Data::Conveyor::Value::Enum;
BEGIN {
  $Data::Conveyor::Value::Enum::VERSION = '1.102250';
}
# ABSTRACT: Stage-based conveyor-belt-like ticket handling system


# Inherit from Class::Scaffold::Base because get_valid_values_list is
# presumably going to ask the delegate. Need to put Class::Value::Enum first
# so it can find the more specific comparable() in Class::Value. If you need
# to ask the storage for the list of valid values, your subclass should
# inherit from Class::Scaffold::Storable instead.
use parent qw(
  Class::Value::Enum
  Class::Scaffold::Base
);
1;


__END__
=pod

=head1 VERSION

version 1.102250

=head1 INSTALLATION

See perlmodinstall for information and options on installing Perl modules.

=head1 BUGS AND LIMITATIONS

No bugs have been reported.

Please report any bugs or feature requests through the web interface at
L<http://rt.cpan.org>.

=head1 AVAILABILITY

The latest version of this module is available from the Comprehensive Perl
Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
site near you, or see
L<http://search.cpan.org/dist/Data-Conveyor/>.

The development version lives at
L<http://github.com/hanekomu/Data-Conveyor/>.
Instead of sending patches, please fork this project using the standard git
and github infrastructure.

=head1 AUTHORS

=over 4

=item *

Marcel Gruenauer <marcel@cpan.org>

=item *

Florian Helmberger <fh@univie.ac.at>

=item *

Achim Adam <ac@univie.ac.at>

=item *

Mark Hofstetter <mh@univie.ac.at>

=item *

Heinz Ekker <ek@univie.ac.at>

=back

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2004 by Marcel Gruenauer.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> Data-Conveyor-1.103010.tar.gz: Data-Conveyor-1.103010/lib/Data/Conveyor/Value/Enum.pm <==
use 5.008;
use strict;
use warnings;

package Data::Conveyor::Value::Enum;
BEGIN {
  $Data::Conveyor::Value::Enum::VERSION = '1.103010';
}
# ABSTRACT: Stage-based conveyor-belt-like ticket handling system


# Inherit from Class::Scaffold::Base because get_valid_values_list is
# presumably going to ask the delegate. Need to put Class::Value::Enum first
# so it can find the more specific comparable() in Class::Value. If you need
# to ask the storage for the list of valid values, your subclass should
# inherit from Class::Scaffold::Storable instead.
use parent qw(
  Class::Value::Enum
  Class::Scaffold::Base
);
1;


__END__
=pod

=head1 NAME

Data::Conveyor::Value::Enum - Stage-based conveyor-belt-like ticket handling system

=head1 VERSION

version 1.103010

=head1 INSTALLATION

See perlmodinstall for information and options on installing Perl modules.

=head1 BUGS AND LIMITATIONS

No bugs have been reported.

Please report any bugs or feature requests through the web interface at
L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Conveyor>.

=head1 AVAILABILITY

The latest version of this module is available from the Comprehensive Perl
Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
site near you, or see L<http://search.cpan.org/dist/Data-Conveyor/>.

The development version lives at L<http://github.com/hanekomu/Data-Conveyor>
and may be cloned from L<git://github.com/hanekomu/Data-Conveyor>.
Instead of sending patches, please fork this project using the standard
git and github infrastructure.

=head1 AUTHORS

=over 4

=item *

Marcel Gruenauer <marcel@cpan.org>

=item *

Florian Helmberger <fh@univie.ac.at>

=item *

Achim Adam <ac@univie.ac.at>

=item *

Mark Hofstetter <mh@univie.ac.at>

=item *

Heinz Ekker <ek@univie.ac.at>

=back

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2004 by Marcel Gruenauer.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
